@@ -6,13 +6,17 @@ use Time::Local;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.04';
+$VERSION = '1.00';
 
 my %months_map = (
     'Jan' => 0, 'Feb' => 1, 'Mar' => 2,
     'Apr' => 3, 'May' => 4, 'Jun' => 5,
     'Jul' => 6, 'Aug' => 7, 'Sep' => 8,
-    'Oct' => 9, 'Nov' =>10, 'Dec' =>11
+    'Oct' => 9, 'Nov' =>10, 'Dec' =>11,
+    'jan' => 0, 'feb' => 1, 'mar' => 2,
+    'apr' => 3, 'may' => 4, 'jun' => 5,
+    'jul' => 6, 'aug' => 7, 'sep' => 8,
+    'oct' => 9, 'nov' =>10, 'dec' =>11,
 );
 
 # fast timelocal
@@ -133,7 +137,7 @@ sub next($)
         my ($host, $text) = ($6, $7);
 
         # last message repeated ... times
-        if($text =~ /^last message repeated (\d+) time/) {
+        if($text =~ /^(?:last message repeated|above message repeats) (\d+) time/) {
             next line if defined $self->{repeat} and not $self->{repeat};
             next line if not defined $self->{_last_data}{$host};
             $1 > 0 or do {
@@ -145,12 +149,19 @@ sub next($)
             return $self->{_last_data}{$host};
         }
 
+        # marks
+        next if $text eq '-- MARK --';
+
         # some systems send over the network their
         # hostname prefixed to the text. strip that.
-        $text =~ s/^[-\w+\.]+\s+//;
+        $text =~ s/^$host\s+//;
+
+        # discard ':' in HP-UX 'su' entries like this:
+        # Apr 24 19:09:40 remedy : su : + tty?? root-oracle
+        $text =~ s/^:\s+//;
 
         $text =~ /^
-            (\S+?)          # program   -- 1
+            ([^:]+?)        # program   -- 1
             (?:\[(\d+)\])?  # PID       -- 2
             :\s+
             (?:\[ID\ (\d+)\ ([a-z0-9]+)\.([a-z]+)\]\ )?   # Solaris 8 "message id" -- 3, 4, 5
@@ -349,6 +360,7 @@ David Schweikert <dws@ee.ethz.ch>
  2001-08-19 ds 0.02 fix 'last message repeated xx times', Solaris 8 problems
  2001-08-20 ds 0.03 implemented GMT option, year specification, File::Tail
  2001-10-31 ds 0.04 faster time parsing, implemented 'arrayref' option, better time-increment algorithm
+ 2002-01-29 ds 0.05 ignore -- MARK -- lines, low-case months, space in program names
 
 =cut
 
